@@ -16,11 +16,12 @@ package mp4
 // TODO: better probe, find first 2 boxes, should be free,ftyp or mdat?
 
 import (
+	"cmp"
 	"embed"
 	"fmt"
+	"strings"
 
 	"github.com/wader/fq/format"
-	"github.com/wader/fq/internal/cmpex"
 	"github.com/wader/fq/pkg/decode"
 	"github.com/wader/fq/pkg/interp"
 	"golang.org/x/exp/slices"
@@ -42,6 +43,7 @@ var hevcCDCRGroup decode.Group
 var iccProfileGroup decode.Group
 var id3v2Group decode.Group
 var imageGroup decode.Group
+var jp2cGroup decode.Group
 var jpegGroup decode.Group
 var mp3FrameGroup decode.Group
 var mpegESGroup decode.Group
@@ -82,6 +84,7 @@ func init() {
 				{Groups: []*decode.Group{format.ICC_Profile}, Out: &iccProfileGroup},
 				{Groups: []*decode.Group{format.ID3v2}, Out: &id3v2Group},
 				{Groups: []*decode.Group{format.Image}, Out: &imageGroup},
+				{Groups: []*decode.Group{format.JP2C}, Out: &jp2cGroup},
 				{Groups: []*decode.Group{format.JPEG}, Out: &jpegGroup},
 				{Groups: []*decode.Group{format.MP3_Frame}, Out: &mp3FrameGroup},
 				{Groups: []*decode.Group{format.MPEG_ES}, Out: &mpegESGroup},
@@ -240,10 +243,10 @@ func mp4Tracks(d *decode.D, ctx *decodeContext) {
 
 	// sort by id then order in file
 	slices.SortStableFunc(tracksCollected, func(a, b *trackCollected) int {
-		if r := cmpex.Compare(a.track.id, b.track.id); r != 0 {
+		if r := cmp.Compare(a.track.id, b.track.id); r != 0 {
 			return r
 		}
-		return cmpex.Compare(a.order, b.order)
+		return cmp.Compare(a.order, b.order)
 	})
 
 	d.FieldArray("tracks", func(d *decode.D) {
@@ -465,14 +468,14 @@ func mp4Decode(d *decode.D) any {
 	if size < 8 {
 		d.Fatalf("first box size too small < 8")
 	}
-	firstType := d.UTF8(4)
+	firstType := strings.TrimSpace(d.UTF8(4))
 	switch firstType {
 	case "styp", // mp4 segment
 		"ftyp", // mp4 file
 		"free", // seems to happen
 		"moov", // seems to happen
 		"pnot", // video preview file
-		"jP  ": // JPEG 2000
+		"jP":   // JPEG 2000
 	default:
 		d.Errorf("no styp, ftyp, free or moov box found")
 	}
