@@ -10,7 +10,7 @@ import (
 
 	"github.com/BurntSushi/toml"
 	"github.com/wader/fq/format"
-	"github.com/wader/fq/internal/gojqex"
+	"github.com/wader/fq/internal/gojqx"
 	"github.com/wader/fq/pkg/bitio"
 	"github.com/wader/fq/pkg/decode"
 	"github.com/wader/fq/pkg/interp"
@@ -69,7 +69,7 @@ func decodeTOML(d *decode.D) any {
 		d.Fatalf("%s", err)
 	}
 	var s scalar.Any
-	s.Actual = gojqex.Normalize(r)
+	s.Actual = gojqx.Normalize(r)
 
 	// TODO: better way to handle that an empty file is valid toml and parsed as an object
 	switch v := s.Actual.(type) {
@@ -90,11 +90,11 @@ func decodeTOML(d *decode.D) any {
 
 func toTOML(_ *interp.Interp, c any) any {
 	if c == nil {
-		return gojqex.FuncTypeError{Name: "to_toml", V: c}
+		return gojqx.FuncTypeError{Name: "to_toml", V: c}
 	}
 
 	b := &bytes.Buffer{}
-	if err := toml.NewEncoder(b).Encode(gojqex.Normalize(c)); err != nil {
+	if err := toml.NewEncoder(b).Encode(gojqx.Normalize(c)); err != nil {
 		return err
 	}
 	return b.String()
