@@ -1,10 +1,10 @@
 package decode
 
 import (
+	"cmp"
 	"errors"
 	"fmt"
 
-	"github.com/wader/fq/internal/cmpex"
 	"github.com/wader/fq/pkg/bitio"
 	"github.com/wader/fq/pkg/ranges"
 	"github.com/wader/fq/pkg/scalar"
@@ -12,26 +12,26 @@ import (
 )
 
 type Compound struct {
-	IsArray     bool
-	Children    []*Value
 	ByName      map[string]*Value
 	Description string
+	Children    []*Value
+	IsArray     bool
 }
 
 // TODO: Encoding, u16le, varint etc, encode?
 // TODO: Value/Compound interface? can have per type and save memory
 // TODO: Make some fields optional somehow? map/slice?
 type Value struct {
-	Parent      *Value
-	Name        string
 	V           any // scalar.S or Compound (array/struct)
-	Index       int // index in parent array/struct
-	Range       ranges.Range
 	RootReader  bitio.ReaderAtSeeker
-	IsRoot      bool    // TODO: rework?
-	Format      *Format // TODO: rework
-	Description string
 	Err         error
+	Parent      *Value
+	Format      *Format // TODO: rework
+	Name        string
+	Description string
+	Range       ranges.Range
+	Index       int  // index in parent array/struct
+	IsRoot      bool // TODO: rework?
 }
 
 type WalkFn func(v *Value, rootV *Value, depth int, rootDepth int) error
@@ -205,7 +205,7 @@ func (v *Value) postProcess() {
 			// sort struct fields and make sure to keep order if range is the same
 			if !vv.IsArray {
 				slices.SortStableFunc(vv.Children, func(a, b *Value) int {
-					return cmpex.Compare(a.Range.Start, b.Range.Start)
+					return cmp.Compare(a.Range.Start, b.Range.Start)
 				})
 			}
 
